@@ -40,9 +40,9 @@
 #include <stdio.h>
 
 #include "mp.h"
+#include "mpmath.h"
 #include "calctool.h"
 #include "display.h"
-#include "functions.h" /* FIXME: Only for show_error() */
 
 #define C_abs(x)    ((x) >= 0 ? (x) : -(x))
 #define dabs(x)     (double) C_abs(x)
@@ -1206,13 +1206,13 @@ L10:
 
     accuracy = v->accuracy;
     dtype = v->dtype;
-    pointed = v->pointed;
-    toclear = v->toclear;
+    pointed = v->ltr.pointed;
+    toclear = v->ltr.toclear;
 
     v->dtype = FIX;
     v->accuracy = MAX_DIGITS;
     mpcmf(&x[1], tmp);
-    STRNCPY(disp, make_number(tmp, v->base, FALSE), MAXLINE - 1);
+    make_number(disp, MAXLINE, tmp, v->base, FALSE);
 
     if (disp[0] == '1') {
         y[ll+1]++;
@@ -1220,8 +1220,8 @@ L10:
 
     v->accuracy = accuracy;
     v->dtype = dtype;
-    v->pointed = pointed;
-    v->toclear = toclear;
+    v->ltr.pointed = pointed;
+    v->ltr.toclear = toclear;
 }
 
 
@@ -3361,7 +3361,7 @@ mppwr2(int *x, int *y, int *z)
     else goto L70;
 
 L10:
-    show_error(_("Negative X and non-integer Y not supported"));
+    display_set_error(_("Negative X and non-integer Y not supported"));
     goto L50;
 
 /* HERE X IS ZERO, RETURN ZERO IF Y POSITIVE, OTHERWISE ERROR */
